#ifndef BetterAuthorizationSampleLib_h
#define BetterAuthorizationSampleLib_h

#include <CoreFoundation/CoreFoundation.h>
#include <Security/Security.h>

#ifdef __cplusplus
extern "C" {
#endif

#define kBASCommandKey             "com.apple.dts.BetterAuthorizationSample.command"
#define kBASErrorKey               "com.apple.dts.BetterAuthorizationSample.error"
#define kBASDescriptorArrayKey     "com.apple.dts.BetterAuthorizationSample.descriptors"

typedef struct {
    const char *commandName;
    const char *rightName;
    const char *rightDefaultRule;
    const char *rightDescriptionKey;
    const void *userData;
} BASCommandSpec;

typedef OSStatus (*BASCommandProc)(
    AuthorizationRef auth,
    const void *userData,
    CFDictionaryRef request,
    CFMutableDictionaryRef response,
    void *asl,
    void *aslMsg
);

OSStatus BASExecuteRequestInHelperTool(
    AuthorizationRef auth,
    const BASCommandSpec commands[],
    CFStringRef bundleID,
    CFDictionaryRef request,
    CFDictionaryRef _Nullable * _Nullable response
);

typedef uint32_t BASFailCode;

enum {
    kBASFailUnknown = 0,
    kBASFailDisabled,
    kBASFailPartiallyInstalled,
    kBASFailNotInstalled,
    kBASFailNeedsUpdate
};

OSStatus BASErrnoToOSStatus(int errNum);

int BASOSStatusToErrno(OSStatus status);

void BASCloseDescriptorArray(CFArrayRef descArray);

#ifdef __cplusplus
}
#endif

#endif /* BetterAuthorizationSampleLib_h */